pecos.decoders.dummy\_decoder.dummy\_decoder
============================================

.. automodule:: pecos.decoders.dummy_decoder.dummy_decoder











   .. rubric:: Classes

   .. autosummary::

      DummyDecoder
